import { CoreMessage, CoreTool as CT, LanguageModelV1 } from 'ai';
import { ZodSchema } from 'zod';
import { AllTools, CoreTool, ToolApi } from '../tools/types';
import { Integration } from '../integration';
import { Logger } from '../logger';
export type OpenAIVercelModelNames = 'gpt-4' | 'gpt-4-turbo' | 'gpt-3.5-turbo' | 'gpt-4o' | 'gpt-4o-mini';
export type OpenAIVercelConfig = {
    provider: 'OPEN_AI_VERCEL';
    name: OpenAIVercelModelNames;
    toolChoice: 'auto' | 'required';
};
export type GoogleVercelModelNames = 'gemini-1.5-pro-latest' | 'gemini-1.5-pro' | 'gemini-1.5-flash-latest' | 'gemini-1.5-flash';
export type GoogleVercelConfig = {
    provider: 'GOOGLE_VERCEL';
    name: GoogleVercelModelNames;
    toolChoice: 'auto' | 'required';
};
export type AnthropicVercelModelNames = 'claude-3-opus-20240229' | 'claude-3-sonnet-20240229' | 'claude-3-haiku-20240307' | 'claude-3-5-sonnet-20240620';
export type AnthropicVercelConfig = {
    provider: 'ANTHROPIC_VERCEL';
    name: AnthropicVercelModelNames;
    toolChoice: 'auto' | 'required';
};
export type GroqVercelModelNames = 'llama3-groq-70b-8192-tool-use-preview' | 'llama3-groq-8b-8192-tool-use-preview' | 'gemma2-9b-it' | 'gemma-7b-it';
export type GroqVercelConfig = {
    provider: 'GROQ_VERCEL';
    name: GroqVercelModelNames;
    toolChoice: 'auto' | 'required';
};
export type ModelConfig = OpenAIVercelConfig | AnthropicVercelConfig | GroqVercelConfig | GoogleVercelConfig;
export declare class LLM<TIntegrations extends Integration[] | undefined = undefined, TTools extends Record<string, ToolApi<TIntegrations>> | undefined = undefined, TKeys extends keyof AllTools<TIntegrations, TTools> = keyof AllTools<TIntegrations, TTools>> {
    #private;
    logger: Logger;
    constructor(logger?: Logger);
    /**
     * Set the concrete tools for the agent
     * @param tools
     */
    __setTools(tools: Record<TKeys, ToolApi>): void;
    getModelType(model: ModelConfig): string;
    createOpenAICompatibleModel(baseURL: string, apiKey: string, defaultModelName: string, modelName?: string): LanguageModelV1;
    createModelDef({ model, }: {
        model: {
            type: string;
            name?: string;
            toolChoice?: 'auto' | 'required';
        };
    }): LanguageModelV1;
    getParams({ tools, resultTool, model, }: {
        tools: Record<string, CoreTool>;
        resultTool?: {
            description: string;
            parameters: ZodSchema;
        };
        model: {
            type: string;
            name?: string;
            toolChoice?: 'auto' | 'required';
        };
    }): {
        toolsConverted: Record<string, CT>;
        modelDef: LanguageModelV1;
        answerTool: {};
        toolChoice: "auto" | "required";
    };
    convertTools(enabledTools?: Partial<Record<TKeys, boolean>>): Record<TKeys, CoreTool>;
    text({ model, messages, onStepFinish, maxSteps, enabledTools, }: {
        enabledTools?: Partial<Record<TKeys, boolean>>;
        model: ModelConfig;
        messages: CoreMessage[];
        onStepFinish?: (step: string) => void;
        maxSteps?: number;
    }): Promise<import("ai").GenerateTextResult<{}>>;
    stream({ model, messages, onStepFinish, onFinish, maxSteps, enabledTools, }: {
        model: ModelConfig;
        enabledTools: Partial<Record<TKeys, boolean>>;
        messages: CoreMessage[];
        onStepFinish?: (step: string) => void;
        onFinish?: (result: string) => Promise<void> | void;
        maxSteps?: number;
    }): Promise<import("ai").StreamTextResult<{}>>;
}
//# sourceMappingURL=index.d.ts.map