export declare const RegisteredLogger: {
    readonly AGENT: "AGENT";
    readonly WORKFLOW: "WORKFLOW";
};
export type RegisteredLogger = (typeof RegisteredLogger)[keyof typeof RegisteredLogger];
export declare const LogLevel: {
    readonly DEBUG: "DEBUG";
    readonly INFO: "INFO";
    readonly WARN: "WARN";
    readonly ERROR: "ERROR";
};
export type LogLevel = (typeof LogLevel)[keyof typeof LogLevel];
export interface BaseLogMessage {
    message: string;
    destinationPath: string;
    type: RegisteredLogger;
}
export interface Logger<T extends BaseLogMessage = BaseLogMessage> {
    debug(message: T | string, ...args: any[]): void | Promise<void>;
    info(message: T | string, ...args: any[]): void | Promise<void>;
    warn(message: T | string, ...args: any[]): void | Promise<void>;
    error(message: T | string, ...args: any[]): void | Promise<void>;
    cleanup?(): Promise<void>;
}
export type LoggerConfig = {
    type: 'CONSOLE';
    level?: LogLevel;
} | {
    type: 'FILE';
    level?: LogLevel;
    dirPath?: string;
} | {
    type: 'UPSTASH';
    level?: LogLevel;
    url: string;
    token: string;
    key?: string;
};
export declare abstract class BaseLogger<T extends BaseLogMessage = BaseLogMessage> implements Logger<T> {
    protected level: LogLevel;
    constructor(level?: LogLevel);
    abstract log(level: LogLevel, message: T | string, ...args: any[]): void | Promise<void>;
    debug(message: T | string, ...args: any[]): void | Promise<void>;
    info(message: T | string, ...args: any[]): void | Promise<void>;
    warn(message: T | string, ...args: any[]): void | Promise<void>;
    error(message: T | string, ...args: any[]): void | Promise<void>;
    protected formatMessage(message: T | string): string;
    protected formatLogEntry(level: LogLevel, message: T | string): any;
}
export declare class MultiLogger<T extends BaseLogMessage = BaseLogMessage> implements Logger<T> {
    private loggers;
    constructor(loggers: Logger<T>[]);
    debug(message: T | string, ...args: any[]): Promise<void>;
    info(message: T | string, ...args: any[]): Promise<void>;
    warn(message: T | string, ...args: any[]): Promise<void>;
    error(message: T | string, ...args: any[]): Promise<void>;
    cleanup(): Promise<void>;
}
export declare function createLogger<T extends BaseLogMessage = BaseLogMessage>(config: LoggerConfig): Logger<T>;
export declare function createMultiLogger<T extends BaseLogMessage = BaseLogMessage>(loggers: Logger<T>[]): Logger<T>;
//# sourceMappingURL=index.d.ts.map