import { ZodSchema } from 'zod';
import { Integration } from '../integration';
import { LLM } from '../llm';
import { MastraEngine } from '../engine';
import { Agent } from '../agent';
export type CoreTool = {
    description: string;
    parameters: ZodSchema;
    execute: (params: any) => Promise<any>;
};
export interface IntegrationApiExcutorParams<TIntegrations extends Integration[] | unknown = unknown, T extends Record<string, any> | Record<string, any> = Record<string, any>> {
    data: T;
    getIntegration: <I extends TIntegrations extends Integration[] ? TIntegrations[number]['name'] : never>(name: I) => TIntegrations extends Integration[] ? Extract<TIntegrations[number], {
        name: I;
    }> : never;
    llm: LLM<TIntegrations extends Integration[] ? TIntegrations : never, any, any>;
    engine: MastraEngine | undefined;
    agents: Map<string, Agent<Integration[], any>>;
}
export type ToolApi<TIntegrations extends Integration[] | unknown = unknown, IN extends Record<string, any> = Record<string, any>, OUT extends Record<string, any> = Record<string, any>> = {
    schema: ZodSchema<IN>;
    label: string;
    description: string;
    documentation?: string;
    executor: (params: IntegrationApiExcutorParams<TIntegrations, IN>) => Promise<OUT>;
};
type ToolRecord<TIntegrations extends Integration[] | undefined> = Record<string, ToolApi<TIntegrations, Record<string, any>, Record<string, any>>>;
export type IntegrationTools<T extends Integration> = T['tools'];
type UnionToIntersection<U> = (U extends any ? (k: U) => void : never) extends (k: infer I) => void ? I : never;
export type MergeIntegrationTools<T extends Integration[]> = UnionToIntersection<IntegrationTools<T[number]>>;
export type AllTools<TIntegrations extends Integration[] | undefined = undefined, TTools extends ToolRecord<TIntegrations> | undefined = undefined> = (TTools extends ToolRecord<TIntegrations> ? TTools : {}) & (TIntegrations extends Integration[] ? MergeIntegrationTools<TIntegrations> : {});
export {};
//# sourceMappingURL=types.d.ts.map